@@ -1,6 +1,7 @@
 """This module contains a wrapper for pandapower grids."""
 from importlib import import_module
 
+import numpy as np
 import pandapower as pp
 import pandapower.networks as pn
 import simbench as sb
@@ -116,6 +117,8 @@ class PandapowerGrid:
                         data[output] = self.grid[etype].iloc[attrs["idx"]][
                             output
                         ]
+                    # if np.isnan(data[output]):
+                    #     data[output] = 0
                 else:
                     data[output] = 0  # Return nan?
 
